VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package KCSKNNShiny

Package {KCSKNNShiny}


Type: Package
Title: K-Nearest Neighbour Classifier
Version: 0.1.0
Author: Karne Chaithanya Sai
Maintainer: Karne Chaithanya Sai <karnechaithanyasai@gmail.com>
Description: It predicts any attribute (categorical) given a set of input numeric predictor values. Note that only numeric input predictors should be given. The k value can be chosen according to accuracies provided. The attribute to be predicted can be selected from the dropdown provided (select categorical attribute). This is because categorical attributes cannot be given as inputs here. A 'handsontable' is also provided to enter the input predictor values.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Imports: shiny, rhandsontable, dplyr, caret, FNN
Repository: CRAN
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2019-07-18 09:00:26 UTC; Mahe
Date/Publication: 2019-07-19 12:30:02 UTC

K-Nearest Neighbour Classifier

Description

This is a KNN Classifier. It predicts any attribute(categorical) given a set of numeric input predictor values. Note that only numeric input predictors should be given. The k value can be chosen according to accuracies provided. The attribute to be predicted can be selected from the dropdown provided(select categorical attribute). This is because categorical attributes cannot be given as inputs here. A 'handsontable' is also provided to enter the input predictor values.

Usage

KCSKNNShiny()

Examples

if(interactive()){KCSKNNShiny()}

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.